@@ -52,7 +52,7 @@ def VisualizeWell(myArr, plot_title=None, plot_z_name=None, export_file=None, cm
 
     if cmap == 'discrete5':
 #    https://stackoverflow.com/questions/9707676/defining-a-discrete-colormap-for-imshow-in-matplotlib
-    	cmap = colors.ListedColormap(['white', 'orange', 'yellow', 'blue', 'green'])
+    	cmap = colors.ListedColormap(['orange', 'yellow', 'blue', 'green'])
 #     	bounds = np.arange(0,5)
 
     plt.figure()
